You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2015/08/04 08:24:51 UTC

[1/2] isis git commit: ISIS-1153: update to facet factory per upgrade to DN 4.1.

Repository: isis
Updated Branches:
  refs/heads/master 20c819c31 -> acc84dfe3


ISIS-1153: update to facet factory per upgrade to DN 4.1.


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/d72efc37
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/d72efc37
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/d72efc37

Branch: refs/heads/master
Commit: d72efc374de8740d614713187067a0921210beaf
Parents: 20c819c
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Tue Aug 4 07:24:21 2015 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Tue Aug 4 07:24:21 2015 +0100

----------------------------------------------------------------------
 ...DatanucleusPersistableTypesFacetFactory.java | 20 ++++++++++++++++--
 .../RemoveDnPrefixedMethodsFacetFactory.java    | 22 +++++++++++++++++---
 2 files changed, 37 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/d72efc37/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDatanucleusPersistableTypesFacetFactory.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDnPrefixedMethodsFacetFactory.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDnPrefixedMethodsFacetFactory.java
index 29f584f..86cbc3a 100644
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDnPrefixedMethodsFacetFactory.java
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDnPrefixedMethodsFacetFactory.java
@@ -1,12 +1,28 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.core.metamodel.facets.object.ignore.datanucleus;
 
+import java.lang.reflect.Method;
+
 import org.apache.isis.core.metamodel.facetapi.FeatureType;
 import org.apache.isis.core.metamodel.facets.FacetFactoryAbstract;
 
-import java.lang.reflect.Method;
-
 /**
- * Removes all methods inherited from <tt>org.datanucleus.enhancer.Persistable</tt> (if DN is on the classpath).
+ * Removes all methods with prefix "dn" (as introduced by DataNucleus enhancement).
  */
 public class RemoveDnPrefixedMethodsFacetFactory extends FacetFactoryAbstract {
 


[2/2] isis git commit: ISIS-1082: adding missing license header files.

Posted by da...@apache.org.
ISIS-1082: adding missing license header files.


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/acc84dfe
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/acc84dfe
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/acc84dfe

Branch: refs/heads/master
Commit: acc84dfe3d64a54cd0339406e335f5dbbc4768c3
Parents: d72efc3
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Tue Aug 4 07:24:35 2015 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Tue Aug 4 07:24:35 2015 +0100

----------------------------------------------------------------------
 .../guides/_cg_committers_release-process.adoc      | 14 +++++++++++++-
 .../services/eventbus/EventBusImplementation.java   | 16 ++++++++++++++++
 .../fixturespec/FixtureScriptsSpecification.java    | 16 ++++++++++++++++
 .../applib/services/guice/GuiceBeanProvider.java    | 16 ++++++++++++++++
 .../ExceptionRecognizerTranslate.java               | 16 ++++++++++++++++
 .../org/apache/isis/schema/utils/Roundtrip.java     | 16 ++++++++++++++++
 .../server/ResourceContextTest_stripQuotes.java     | 16 ++++++++++++++++
 .../viewer/services/GuiceBeanProviderWicket.java    | 16 ++++++++++++++++
 .../ui/components/widgets/favicon/Favicon.java      | 16 ++++++++++++++++
 9 files changed, 141 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/adocs/documentation/src/main/asciidoc/guides/_cg_committers_release-process.adoc
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/guides/_cg_committers_release-process.adoc b/adocs/documentation/src/main/asciidoc/guides/_cg_committers_release-process.adoc
index 344aa77..c110b7f 100644
--- a/adocs/documentation/src/main/asciidoc/guides/_cg_committers_release-process.adoc
+++ b/adocs/documentation/src/main/asciidoc/guides/_cg_committers_release-process.adoc
@@ -73,10 +73,16 @@ Obviously, don't update Apache Isis' `SNAPSHOT` references; these get updated by
 
 == Releasing Core
 
-First, we release `core`.
+First, we release `core`.  Switch to the appropriate directory:
+
+[source,bash]
+----
+cd core
+----
 
 === Set environment variables
 
+
 We use environment variables to parameterize as many of the steps as possible.
 
 [source,bash]
@@ -352,6 +358,12 @@ You may (again) be prompted for gpg passphrase.  All being well this command wil
 
 Apache Isis archetypes are reverse engineered from example applications. Once reverse engineered, the source is checked into git (replacing any earlier version of the archetype) and released.
 
+Switch to the directory containing the `simpleapp` example:
+
+[source,bash]
+----
+cd ../example/application/simpleapp
+----
 
 === Setup environment variables
 

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusImplementation.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusImplementation.java b/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusImplementation.java
index 4617c67..6b9df50 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusImplementation.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusImplementation.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.applib.services.eventbus;
 
 

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/applib/src/main/java/org/apache/isis/applib/services/fixturespec/FixtureScriptsSpecification.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/services/fixturespec/FixtureScriptsSpecification.java b/core/applib/src/main/java/org/apache/isis/applib/services/fixturespec/FixtureScriptsSpecification.java
index d6ace0a..9d8646c 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/services/fixturespec/FixtureScriptsSpecification.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/services/fixturespec/FixtureScriptsSpecification.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.applib.services.fixturespec;
 
 import org.apache.isis.applib.annotation.Programmatic;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/applib/src/main/java/org/apache/isis/applib/services/guice/GuiceBeanProvider.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/services/guice/GuiceBeanProvider.java b/core/applib/src/main/java/org/apache/isis/applib/services/guice/GuiceBeanProvider.java
index 890b062..0e5ebd3 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/services/guice/GuiceBeanProvider.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/services/guice/GuiceBeanProvider.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.applib.services.guice;
 
 import java.lang.annotation.Annotation;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/integtestsupport/src/main/java/org/apache/isis/core/integtestsupport/ExceptionRecognizerTranslate.java
----------------------------------------------------------------------
diff --git a/core/integtestsupport/src/main/java/org/apache/isis/core/integtestsupport/ExceptionRecognizerTranslate.java b/core/integtestsupport/src/main/java/org/apache/isis/core/integtestsupport/ExceptionRecognizerTranslate.java
index 5e9fa60..d9731cc 100644
--- a/core/integtestsupport/src/main/java/org/apache/isis/core/integtestsupport/ExceptionRecognizerTranslate.java
+++ b/core/integtestsupport/src/main/java/org/apache/isis/core/integtestsupport/ExceptionRecognizerTranslate.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.core.integtestsupport;
 
 import java.util.List;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/schema/src/test/java/org/apache/isis/schema/utils/Roundtrip.java
----------------------------------------------------------------------
diff --git a/core/schema/src/test/java/org/apache/isis/schema/utils/Roundtrip.java b/core/schema/src/test/java/org/apache/isis/schema/utils/Roundtrip.java
index 0e62313..20e64b7 100644
--- a/core/schema/src/test/java/org/apache/isis/schema/utils/Roundtrip.java
+++ b/core/schema/src/test/java/org/apache/isis/schema/utils/Roundtrip.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.schema.utils;
 
 import java.io.CharArrayReader;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/viewer-restfulobjects-server/src/test/java/org/apache/isis/viewer/restfulobjects/server/ResourceContextTest_stripQuotes.java
----------------------------------------------------------------------
diff --git a/core/viewer-restfulobjects-server/src/test/java/org/apache/isis/viewer/restfulobjects/server/ResourceContextTest_stripQuotes.java b/core/viewer-restfulobjects-server/src/test/java/org/apache/isis/viewer/restfulobjects/server/ResourceContextTest_stripQuotes.java
index c1b9bbe..95e18f7 100644
--- a/core/viewer-restfulobjects-server/src/test/java/org/apache/isis/viewer/restfulobjects/server/ResourceContextTest_stripQuotes.java
+++ b/core/viewer-restfulobjects-server/src/test/java/org/apache/isis/viewer/restfulobjects/server/ResourceContextTest_stripQuotes.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.viewer.restfulobjects.server;
 
 import org.junit.Test;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/viewer-wicket/impl/src/main/java/org/apache/isis/viewer/wicket/viewer/services/GuiceBeanProviderWicket.java
----------------------------------------------------------------------
diff --git a/core/viewer-wicket/impl/src/main/java/org/apache/isis/viewer/wicket/viewer/services/GuiceBeanProviderWicket.java b/core/viewer-wicket/impl/src/main/java/org/apache/isis/viewer/wicket/viewer/services/GuiceBeanProviderWicket.java
index de426b6..f963ce8 100644
--- a/core/viewer-wicket/impl/src/main/java/org/apache/isis/viewer/wicket/viewer/services/GuiceBeanProviderWicket.java
+++ b/core/viewer-wicket/impl/src/main/java/org/apache/isis/viewer/wicket/viewer/services/GuiceBeanProviderWicket.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.viewer.wicket.viewer.services;
 
 import java.lang.annotation.Annotation;

http://git-wip-us.apache.org/repos/asf/isis/blob/acc84dfe/core/viewer-wicket/ui/src/main/java/org/apache/isis/viewer/wicket/ui/components/widgets/favicon/Favicon.java
----------------------------------------------------------------------
diff --git a/core/viewer-wicket/ui/src/main/java/org/apache/isis/viewer/wicket/ui/components/widgets/favicon/Favicon.java b/core/viewer-wicket/ui/src/main/java/org/apache/isis/viewer/wicket/ui/components/widgets/favicon/Favicon.java
index 622dffa..f566271 100644
--- a/core/viewer-wicket/ui/src/main/java/org/apache/isis/viewer/wicket/ui/components/widgets/favicon/Favicon.java
+++ b/core/viewer-wicket/ui/src/main/java/org/apache/isis/viewer/wicket/ui/components/widgets/favicon/Favicon.java
@@ -1,3 +1,19 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.viewer.wicket.ui.components.widgets.favicon;
 
 import com.google.inject.Inject;
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDatanucleusPersistableTypesFacetFactory.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDatanucleusPersistableTypesFacetFactory.java
index c897656..da22e87 100644
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDatanucleusPersistableTypesFacetFactory.java
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDatanucleusPersistableTypesFacetFactory.java
@@ -1,14 +1,30 @@
+/**
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 package org.apache.isis.core.metamodel.facets.object.ignore.datanucleus;
 
 import org.apache.isis.core.metamodel.facets.object.ignore.javalang.AbstractRemoveMethodsFacetFactory;
 
 /**
  * Removes all methods inherited from <tt>org.datanucleus.enhancer.Persistable</tt> (if datanucleus 4.x is on the classpath).
  */
 public class RemoveDatanucleusPersistableTypesFacetFactory extends AbstractRemoveMethodsFacetFactory {
 
     public RemoveDatanucleusPersistableTypesFacetFactory() {
-        super("org.datanucleus.enhancer.Persistable");
+        super("org.datanucleus.enhancement.Persistable");
     }
 
 }

http://git-wip-us.apache.org/repos/asf/isis/blob/d72efc37/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/ignore/datanucleus/RemoveDnPrefixedMethodsFacetFactory.java
----------------------------------------------------------------------
@@ -1,14 +1,30 @@
 
 /**
- * Removes all methods inherited from <tt>org.datanucleus.enhancer.Persistable</tt> (if datanucleus 4.x is on the classpath).
+ * Removes all methods inherited from <tt>org.datanucleus.enhancement.Persistable</tt> (if datanucleus 4.1.x is on the classpath).
  */
 public class RemoveDatanucleusPersistableTypesFacetFactory extends AbstractRemoveMethodsFacetFactory {